@@ -6,6 +6,7 @@ use Dancer::Plugin::DBIC 'schema';
 use App::Netdisco::Util::Device qw/get_device is_discoverable/;
 use App::Netdisco::Util::DNS ':all';
 use NetAddr::IP::Lite ':lower';
+use Encode;
 use Try::Tiny;
 
 use base 'Exporter';
@@ -192,7 +193,7 @@ sub store_interfaces {
   foreach my $entry (keys %$interfaces) {
       my $port = $interfaces->{$entry};
 
-      if (not length $port) {
+      if (not $port) {
           debug sprintf ' [%s] interfaces - ignoring %s (no port mapping)',
             $device->ip, $port;
           next;
@@ -288,7 +289,7 @@ sub store_wireless {
       (my $iid = $entry) =~ s/\.\d+$//;
       my $port = $interfaces->{$iid};
 
-      if (not length $port) {
+      if (not $port) {
           debug sprintf ' [%s] wireless - ignoring %s (no port mapping)',
             $device->ip, $port;
           next;
@@ -316,7 +317,7 @@ sub store_wireless {
   foreach my $entry (keys %$channel) {
       my $port = $interfaces->{$entry};
 
-      if (not length $port) {
+      if (not $port) {
           debug sprintf ' [%s] wireless - ignoring %s (no port mapping)',
             $device->ip, $port;
           next;
@@ -611,9 +612,9 @@ sub store_neighbors {
       my $remote_ipad = NetAddr::IP::Lite->new($remote_ip);
       my $remote_port = undef;
       my $remote_type = $c_platform->{$entry};
-      my $remote_id   = $c_id->{$entry};
+      my $remote_id   = Encode::decode('UTF-8', $c_id->{$entry});
 
-      next unless length $remote_ip;
+      next unless $remote_ip;
 
       # a bunch of heuristics to search known devices if we don't have a
       # useable remote IP...
