@@ -5,6 +5,9 @@ use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
 
 use App::Netdisco::Web::Plugin;
+use App::Netdisco::Util::Device 'get_device';
+
+use Try::Tiny;
 use NetAddr::IP::Lite ':lower';
 
 register_admin_task({
@@ -21,8 +24,8 @@ sub _sanity_ok {
     my $dev2 = NetAddr::IP::Lite->new(param('dev2'));
     return 0 unless ($dev2 and $dev2->addr ne '0.0.0.0');
 
-    return 0 unless length param('port1');
-    return 0 unless length param('port2');
+    return 0 unless param('port1');
+    return 0 unless param('port2');
 
     return 1;
 }
@@ -50,7 +53,8 @@ ajax '/ajax/control/admin/topology/add' => sub {
           return unless ($left->in_storage and $right->in_storage);
 
           $left->ports
-            ->single({port => param('port1')}, {for => 'update'})
+            ->search({port => param('port1')}, {for => 'update'})
+            ->single()
             ->update({
               remote_ip => param('dev2'),
               remote_port => param('port2'),
@@ -61,7 +65,8 @@ ajax '/ajax/control/admin/topology/add' => sub {
             });
 
           $right->ports
-            ->single({port => param('port2')}, {for => 'update'})
+            ->search({port => param('port2')}, {for => 'update'})
+            ->single()
             ->update({
               remote_ip => param('dev1'),
               remote_port => param('port1'),
