@@ -9,12 +9,12 @@ use Net::MAC ();
 
 use App::Netdisco::Web::Plugin;
 
-register_search_tab({ id => 'node', label => 'Node' });
+register_search_tab({ tag => 'node', label => 'Node' });
 
 # nodes matching the param as an IP or DNS hostname or MAC
 ajax '/ajax/content/search/node' => sub {
     my $node = param('q');
-    return unless $node;
+    send_error('Missing node', 400) unless $node;
     content_type('text/html');
 
     my $mac = Net::MAC->new(mac => $node, 'die' => 0, verbose => 0);
@@ -60,6 +60,7 @@ ajax '/ajax/content/search/node' => sub {
               ->search_by_dns({dns => $node, @active});
         }
         return unless $set and $set->count;
+        $set = $set->search_rs({}, { order_by => 'me.mac' });
 
         template 'ajax/search/node_by_ip.tt', {
           macs => $set,
